==> cricketr_0.0.11.tar.gz: cricketr/README.md <==
# cricketr
This R package can be used to analyze performances of cricketers based on stats from ESPN Cricinfo.

The package be installed as follows
library(devtools)
install_github("tvganesh/cricketr")
library(cricketr)

Details of this package has been hosted as a gh-page in [Introducing cricketr: A R package for analyzing performances of cricketer](http://tvganesh.github.io/cricketer/cricketer.html)

Also see my other posts in R and cricket

1. [A peek into literacy in India: Statistical Learning with R](https://gigadom.wordpress.com/2015/01/05/a-peek-into-literacy-in-india-statistical-learning-with-r/)
2. [A crime map of India in R – Crimes against women](https://gigadom.wordpress.com/2015/01/16/a-crime-map-of-india-in-r-crime-against-women/)
3. [Analyzing cricket’s batting legends – Through the mirage with R](https://gigadom.wordpress.com/2015/02/06/analyzing-crickets-batting-legends-through-the-mirage-with-r/)
4. [Masters of Spin: Unraveling the web with R](https://gigadom.wordpress.com/2015/02/23/masters-of-spin-unraveling-the-web-with-r/)
5. [Mirror, mirror … the best batsman of them all?](https://gigadom.wordpress.com/2015/03/24/mirror-mirror-the-best-batsman-of-them-all/)
6. [Informed choices through Machine Learning - Analyzing Kohli, Tendulkar and Dravid](https://gigadom.wordpress.com/2014/12/12/informed-choices-through-machine-learning-analyzing-kohli-tendulkar-and-dravid/)
7. [Informed choices through Machine Learning-2: Pitting together Kumble, Kapil, Chandra](https://gigadom.wordpress.com/2014/12/17/informed-choices-through-machine-learning-2-pitting-together-kumble-kapil-chandra/)

==> cricketr_0.0.13.tar.gz: cricketr/README.md <==
# cricketr
This R package can be used to analyze performances of cricketers based on stats from ESPN Cricinfo.

The package be installed directly from CRAN as
install.packages("cricketr")

or from Github as follows
library(devtools)
install_github("tvganesh/cricketr")
library(cricketr)

Details of this package can be read from my blog Giga thoughts in [Introducing cricketr: A R package for analyzing performances of cricketer](https://gigadom.wordpress.com/2015/07/04/introducing-cricketr-a-r-package-to-analyze-performances-of-cricketers/)

Also see my other posts in R and cricket

1. [A peek into literacy in India: Statistical Learning with R](https://gigadom.wordpress.com/2015/01/05/a-peek-into-literacy-in-india-statistical-learning-with-r/)
2. [A crime map of India in R – Crimes against women](https://gigadom.wordpress.com/2015/01/16/a-crime-map-of-india-in-r-crime-against-women/)
3. [Analyzing cricket’s batting legends – Through the mirage with R](https://gigadom.wordpress.com/2015/02/06/analyzing-crickets-batting-legends-through-the-mirage-with-r/)
4. [Masters of Spin: Unraveling the web with R](https://gigadom.wordpress.com/2015/02/23/masters-of-spin-unraveling-the-web-with-r/)
5. [Mirror, mirror … the best batsman of them all?](https://gigadom.wordpress.com/2015/03/24/mirror-mirror-the-best-batsman-of-them-all/)
6. [Informed choices through Machine Learning - Analyzing Kohli, Tendulkar and Dravid](https://gigadom.wordpress.com/2014/12/12/informed-choices-through-machine-learning-analyzing-kohli-tendulkar-and-dravid/)
7. [Informed choices through Machine Learning-2: Pitting together Kumble, Kapil, Chandra](https://gigadom.wordpress.com/2014/12/17/informed-choices-through-machine-learning-2-pitting-together-kumble-kapil-chandra/)
